@@ -4,7 +4,7 @@ matPercs <- function(archoids,data){
     percs[[j]] <- sapply(1 : dim(data)[2], percentilsArchetypoid,
                          archoids[j], data, 0)
   }
-  mat <- matrix(unlist(percs), nrow = 6,
+  mat <- matrix(unlist(percs), nrow = ncol(data),
                   ncol = length(percs), byrow = FALSE)
   return(mat)
 }
\ No newline at end of file
